@@ -318,9 +318,12 @@ add_folder_cb (GtkWidget *widget,
 					     GTK_WINDOW (data->window->app),
 					     GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
 					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					     FR_STOCK_ADD, GTK_RESPONSE_OK,
+					     FR_STOCK_ADD_FOLDER, GTK_RESPONSE_OK,
 					     GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 					     NULL);
+	
+	gtk_window_set_default_size (GTK_WINDOW (data->dialog), 530, 510);
+					     
 	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (file_sel), FALSE);
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (file_sel), TRUE);
 	gtk_dialog_set_default_response (GTK_DIALOG (file_sel), GTK_RESPONSE_OK);
@@ -547,11 +550,12 @@ aod_apply_cb (GtkWidget *widget,
 
 	/* Sync widgets with options. */
 
-	if (base_dir != NULL) 
-		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (data->dialog), base_dir);
-
-	if (filename != NULL)
-		gtk_file_chooser_select_filename (GTK_FILE_CHOOSER (data->dialog), filename);
+	if (base_dir != NULL) { 
+		if ((filename != NULL) && (strcmp (filename, base_dir) != 0)) 
+			gtk_file_chooser_select_filename (GTK_FILE_CHOOSER (data->dialog), filename);
+		else
+			gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (data->dialog), base_dir);
+	}
 		
 	if (include_files != NULL)
 		gtk_entry_set_text (GTK_ENTRY (data->include_files_entry), include_files);
