@@ -161,6 +161,13 @@ dir_contains_one_object (const char *path)
 }
 
 
+gboolean 
+dir_is_temp_dir (const char *dir) {
+	const char *tmp_dir = g_get_tmp_dir ();
+	return (strncmp (dir, tmp_dir, strlen (tmp_dir)) == 0);
+}
+
+
 /* Check whether the path_src is contained in path_dest */
 gboolean
 path_in_path (const char  *path_src,
@@ -358,6 +365,30 @@ file_name_from_path (const gchar *file_name)
 }
 
 
+char *
+dir_name_from_path (const gchar *path)
+{
+	register  gssize base;
+	register  gssize last_char;
+
+	if (path == NULL) 
+		return NULL;
+
+	if (path[0] == '\0')
+		return g_strdup ("");
+
+	last_char = strlen (path) - 1;
+	if (path[last_char] == G_DIR_SEPARATOR) 
+		last_char--;
+
+	base = last_char;
+	while ((base >= 0) && (path[base] != G_DIR_SEPARATOR))
+		base--;	
+	
+	return g_strndup (path + base + 1, last_char - base);
+}
+
+
 gchar *
 remove_level_from_path (const gchar *path)
 {
@@ -471,6 +502,13 @@ is_mime_type (const char* type, const char* pattern) {
 }
 
 
+G_CONST_RETURN char*
+get_mime_type (const char  *filename)
+{
+	return gnome_vfs_get_mime_type_for_name (filename);
+}
+
+
 void
 path_list_free (GList *path_list)
 {
@@ -613,8 +651,10 @@ char *
 get_temp_work_dir (void)
 {
 	char temp_dir_template[] = "/tmp/fr-XXXXXX";
-	g_assert (mkdtemp (temp_dir_template) != NULL);
-	return g_strdup (temp_dir_template);
+	if (mkdtemp (temp_dir_template) == NULL)
+		return NULL;
+	else
+		return g_strdup (temp_dir_template);
 }
 
 
