@@ -40,6 +40,8 @@
 gboolean            path_is_file                 (const gchar *s);
 gboolean            path_is_dir                  (const gchar *s);
 gboolean            dir_is_empty                 (const gchar *s);
+gboolean            dir_contains_one_object      (const char  *path);
+gboolean            dir_is_temp_dir              (const char  *dir);
 gboolean            path_in_path                 (const char  *path_src,
 						  const char  *path_dest);
 GnomeVFSFileSize    get_file_size                (const gchar *s);
@@ -54,6 +56,7 @@ gboolean            ensure_dir_exists            (const gchar *a_path,
 						  mode_t       mode);
 gboolean            file_is_hidden               (const gchar *name);
 G_CONST_RETURN char*file_name_from_path          (const gchar *path);
+char *              dir_name_from_path           (const gchar *path);
 gchar *             remove_level_from_path       (const gchar *path);
 gchar *             remove_extension_from_path   (const gchar *path);
 gchar *             remove_ending_separator      (const gchar *path);
@@ -63,6 +66,7 @@ void                path_list_free               (GList *path_list);
 GList *             path_list_dup                (GList *path_list);
 gboolean            is_mime_type                 (const char* type, 
 						  const char* pattern);
+G_CONST_RETURN char*get_mime_type                (const char  *filename);
 GnomeVFSFileSize    get_dest_free_space          (const char  *path);
 gboolean            rmdir_recursive              (const gchar *directory);
 char *              get_temp_work_dir            (void);
