@@ -172,10 +172,13 @@ process_line (char     *line,
 	g_strfreev (fields);
 	g_free (field_name);
 
-	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
+	fdata->dir = line[0] == 'd';
+	if (fdata->dir)
+		fdata->name =  dir_name_from_path (fdata->full_path);
+	else
+		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	fdata->type = gnome_vfs_mime_type_from_name_or_default (fdata->name, GNOME_VFS_MIME_TYPE_UNKNOWN);
-
+	
 	if (*fdata->name == 0)
 		file_data_free (fdata);
 	else 
@@ -226,9 +229,8 @@ begin_tar_command (FRCommand *comm)
 
 	command = g_find_program_in_path ("gtar");
 #if defined (__SVR4) && defined (__sun)
-	if (g_file_test ("/usr/sfw/bin/gtar", G_FILE_TEST_IS_EXECUTABLE)) {
+	if (g_file_test ("/usr/sfw/bin/gtar", G_FILE_TEST_IS_EXECUTABLE))
 		command = g_strdup ("/usr/sfw/bin/gtar");
-	}
 #endif
 	if (command != NULL)
 		fr_process_begin_command (comm->process, command);
@@ -239,7 +241,8 @@ begin_tar_command (FRCommand *comm)
 
 
 static void
-fr_command_tar_list (FRCommand *comm)
+fr_command_tar_list (FRCommand  *comm,
+		     const char *password)
 {
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
 				      process_line,
@@ -307,6 +310,7 @@ fr_command_tar_add (FRCommand     *comm,
 
 	begin_tar_command (comm);
 	fr_process_add_arg (comm->process, "--force-local");
+	fr_process_add_arg (comm->process, "--no-recursion");
 	fr_process_add_arg (comm->process, "-v");
 	fr_process_add_arg (comm->process, "-p");
 
@@ -644,7 +648,7 @@ get_temp_name (FRCommandTar *c_tar,
 		char *tmp_file_name;
 		g_free (temp_name);
 		g_free (uncomp_temp_name);
-		tmp_file_name = g_strdup_printf ("fr.%d.%d.%s", 
+		tmp_file_name = g_strdup_printf (".fr.%d.%d.%s", 
 						 getpid (), 
 						 count++, 
 						 filename);
@@ -762,7 +766,7 @@ fr_command_tar_escape (FRCommand     *comm,
 	char *estr3;
 
         estr = escape_str (str, "\\");
-        estr2 = escape_str (estr, "\\$?*'& !|()@#:;");
+        estr2 = escape_str (estr, "\\$?*'& !|()@#:;<>");
         estr3 = escape_str_common (estr2, "[]", '[', ']');
 
 	g_free (estr);
@@ -804,7 +808,8 @@ fr_command_tar_init (FRCommand *comm)
 
 	comm->propCanModify                = TRUE;
 	comm->propAddCanUpdate             = TRUE;
-	comm->propAddCanReplace            = FALSE; 
+	comm->propAddCanReplace            = FALSE;
+	comm->propAddCanStoreFolders       = TRUE; 
 	comm->propExtractCanAvoidOverwrite = FALSE;
 	comm->propExtractCanSkipOlder      = FALSE;
 	comm->propExtractCanJunkPaths      = FALSE;
